@@ -20,7 +20,7 @@ class ComputeCentroidsCUDA(CustomKernel):
     self._use_torch_in_cupy_malloc()
     self.stream = Stream(torch.cuda.current_stream().cuda_stream)
 
-    with open(get_absolute_path("kernels", "ComputeCentroidsKernel.cu"), "r") as f:
+    with open(get_absolute_path("kmeans", "kernels", "ComputeCentroidsKernel.cu"), "r") as f:
       self.kernel = f.read()
 
     kernel = (self.kernel
